aboutsummaryrefslogtreecommitdiffstats
path: root/_zsh/60-zle.zsh
diff options
context:
space:
mode:
Diffstat (limited to '_zsh/60-zle.zsh')
-rw-r--r--_zsh/60-zle.zsh4
1 files changed, 2 insertions, 2 deletions
diff --git a/_zsh/60-zle.zsh b/_zsh/60-zle.zsh
index f76f748..92c339d 100644
--- a/_zsh/60-zle.zsh
+++ b/_zsh/60-zle.zsh
@@ -6,11 +6,11 @@
# 2016-05-29
#
# Turn off ZLE bracketed paste in dumb term,
# otherwise turn on ZLE bracketed-paste-magic
# Credit: http://zmwangx.github.io/blog/2015-09-21-zsh-51-and-bracketed-paste.html
# See also zshparam(1)
-if [[ ${TERM} == dumb ]]; then
+if [[ ${TERM} == dumb ]] || [[ ${TERM} == cons25 ]]; then
unset zle_bracketed_paste
else
autoload -Uz bracketed-paste-magic
@@ -6,11 +6,11 @@
# 2016-05-29
#
-# Turn off ZLE bracketed paste in dumb term,
+# Turn off ZLE bracketed paste in dumb and cons25 (DFly default console) term,
# otherwise turn on ZLE bracketed-paste-magic
# Credit: http://zmwangx.github.io/blog/2015-09-21-zsh-51-and-bracketed-paste.html